#hub protocol
SIGNALR = "v2.0/signalr"
SIGNALR_METHOD = "Broadcast"
SIGNALR_ERROR_METHOD = "Error"
SIGNALR_HUB_MD = "FcMarketDataV2Hub"




#api link
# MD_GEN_TOKEN = 'api/v2/Market/GenerateToken'
MD_ACCESS_TOKEN = 'api/v2/Market/AccessToken'

MD_SECURITIES = 'api/v2/Market/Securities'
MD_SECURITIES_DETAILS = 'api/v2/Market/SecuritiesDetails'
MD_INDEX_COMPONENTS = 'api/v2/Market/IndexComponents'
MD_INDEX_LIST = 'api/v2/Market/IndexList'
MD_DAILY_OHLC = 'api/v2/Market/DailyOhlc'
MD_INTRADAY_OHLC = 'api/v2/Market/IntradayOhlc'
MD_DAILY_INDEX = 'api/v2/Market/DailyIndex'
MD_DAILY_STOCK_PRICE = 'api/v2/Market/DailyStockPrice'
MD_BACKTEST = 'api/v2/Market/BackTest'
